@@ -14,6 +14,17 @@ import (
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
+var defaultROBHeader = model1.Header{
+	model1.HeaderColumn{Name: "NAMESPACE"},
+	model1.HeaderColumn{Name: "NAME"},
+	model1.HeaderColumn{Name: "ROLE"},
+	model1.HeaderColumn{Name: "KIND"},
+	model1.HeaderColumn{Name: "SUBJECTS"},
+	model1.HeaderColumn{Name: "LABELS", Attrs: model1.Attrs{Wide: true}},
+	model1.HeaderColumn{Name: "VALID", Attrs: model1.Attrs{Wide: true}},
+	model1.HeaderColumn{Name: "AGE", Attrs: model1.Attrs{Time: true}},
+}
+
 // RoleBinding renders a K8s RoleBinding to screen.
 type RoleBinding struct {
 	Base
@@ -21,37 +32,22 @@ type RoleBinding struct {
 
 // Header returns a header row.
 func (r RoleBinding) Header(_ string) model1.Header {
-	return r.doHeader(r.defaultHeader())
-}
-
-func (RoleBinding) defaultHeader() model1.Header {
-	return model1.Header{
-		model1.HeaderColumn{Name: "NAMESPACE"},
-		model1.HeaderColumn{Name: "NAME"},
-		model1.HeaderColumn{Name: "ROLE"},
-		model1.HeaderColumn{Name: "KIND"},
-		model1.HeaderColumn{Name: "SUBJECTS"},
-		model1.HeaderColumn{Name: "LABELS", Attrs: model1.Attrs{Wide: true}},
-		model1.HeaderColumn{Name: "VALID", Attrs: model1.Attrs{Wide: true}},
-		model1.HeaderColumn{Name: "AGE", Attrs: model1.Attrs{Time: true}},
-	}
+	return r.doHeader(defaultROBHeader)
 }
 
 // Render renders a K8s resource to screen.
-func (r RoleBinding) Render(o interface{}, ns string, row *model1.Row) error {
+func (r RoleBinding) Render(o any, _ string, row *model1.Row) error {
 	raw, ok := o.(*unstructured.Unstructured)
 	if !ok {
-		return fmt.Errorf("expected RoleBinding, but got %T", o)
+		return fmt.Errorf("expected Unstructured, but got %T", o)
 	}
-
 	if err := r.defaultRow(raw, row); err != nil {
 		return err
 	}
 	if r.specs.isEmpty() {
 		return nil
 	}
-
-	cols, err := r.specs.realize(raw, r.defaultHeader(), row)
+	cols, err := r.specs.realize(raw, defaultROBHeader, row)
 	if err != nil {
 		return err
 	}
@@ -60,7 +56,7 @@ func (r RoleBinding) Render(o interface{}, ns string, row *model1.Row) error {
 	return nil
 }
 
-func (r RoleBinding) defaultRow(raw *unstructured.Unstructured, row *model1.Row) error {
+func (RoleBinding) defaultRow(raw *unstructured.Unstructured, row *model1.Row) error {
 	var rb rbacv1.RoleBinding
 	err := runtime.DefaultUnstructuredConverter.FromUnstructured(raw.Object, &rb)
 	if err != nil {
@@ -69,7 +65,7 @@ func (r RoleBinding) defaultRow(raw *unstructured.Unstructured, row *model1.Row)
 
 	kind, ss := renderSubjects(rb.Subjects)
 
-	row.ID = client.MetaFQN(rb.ObjectMeta)
+	row.ID = client.MetaFQN(&rb.ObjectMeta)
 	row.Fields = model1.Fields{
 		rb.Namespace,
 		rb.Name,
@@ -87,7 +83,7 @@ func (r RoleBinding) defaultRow(raw *unstructured.Unstructured, row *model1.Row)
 // ----------------------------------------------------------------------------
 // Helpers...
 
-func renderSubjects(ss []rbacv1.Subject) (kind string, subjects string) {
+func renderSubjects(ss []rbacv1.Subject) (kind, subjects string) {
 	if len(ss) == 0 {
 		return NAValue, ""
 	}
@@ -101,7 +97,7 @@ func renderSubjects(ss []rbacv1.Subject) (kind string, subjects string) {
 }
 
 func toSubjectAlias(s string) string {
-	if len(s) == 0 {
+	if s == "" {
 		return s
 	}
 
